<?php
/* ======================================================
 # Display Date and Time for Joomla! - v2.4.0 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v4.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://demo.web357.com/joomla/date-time
 # Support: support@web357.com
 # Last modified: Saturday 06 April 2024, 02:13:21 AM
 ========================================================= */
 
defined( '_JEXEC' ) or die( 'Restricted access' ); 
use Joomla\CMS\Factory;

$lang = Factory::getLanguage();
$locale = $lang->getTag();  // This will return something like "en-GB" or "el-GR"
$languageCode = substr($locale, 0, 2); // el, en, fr, de, etc.

// CSS Style
$document->addStyleSheet($host.'modules/mod_datetime/tmpl/default.css');
$document->addScript($host.'modules/mod_datetime/tmpl/default.js'); 
// TODO: Download all locales from here https://cdn.jsdelivr.net/npm/dayjs@1/locale/
if ($languageCode == 'el')
{
    $document->addScript($host.'modules/mod_datetime/assets/js/el.js'); 
}
else
{
    $document->addScript('https://cdn.jsdelivr.net/npm/dayjs@1/locale/'.$languageCode.'.js'); 
}

if (!empty($custom_date_format) && isset($timezone) && !empty($timezone)) {
    $javascript = <<<JS
    document.addEventListener('DOMContentLoaded', function () {
        // Assuming you've included dayjs and the Greek locale already
        dayjs.locale(`$languageCode`);
        dayjs.extend(dayjs_plugin_utc);
        dayjs.extend(dayjs_plugin_timezone);

        // DATE
        const mod_dateElement = document.getElementById(`mod_date_js_$moduleId`);

        function modUpdateDate() {
            const currentDate = dayjs()
                .tz(`$timezone`)
                .format(`$custom_date_format`); // YYYY-MM-DD HH:mm:ss
            mod_dateElement.textContent = currentDate;
        }

        // Update the time immediately upon script load
        modUpdateDate();

        // Then update it every second (1000 milliseconds)
        setInterval(modUpdateDate, 1000);
    });
    JS;

}elseif (!empty($custom_date_format) && (!isset($timezone) || empty($timezone))) {
    
    $javascript = <<<JS
    document.addEventListener('DOMContentLoaded', function () {
        // Assuming you've included dayjs and the Greek locale already
        dayjs.locale(`$languageCode`);
        dayjs.extend(dayjs_plugin_utc);
        dayjs.extend(dayjs_plugin_timezone);

        // DATE
        const mod_dateElement = document.getElementById(`mod_date_js_$moduleId`);

        function modUpdateDate() {
            const currentDate = dayjs()
                .format(`$custom_date_format`); // YYYY-MM-DD HH:mm:ss
            mod_dateElement.textContent = currentDate;
        }

        // Update the time immediately upon script load
        modUpdateDate();

        // Then update it every second (1000 milliseconds)
        setInterval(modUpdateDate, 1000);
    });
JS;
}
Factory::getDocument()->addScriptDeclaration($javascript);

if ($timeformat == 2 || $timeformat == 3)
{
    if (isset($timezone) && !empty($timezone)) {
        $javascript = <<<JS
        document.addEventListener('DOMContentLoaded', function () {
            // Assuming you've included dayjs and the Greek locale already
            dayjs.locale(`$languageCode`);
            dayjs.extend(dayjs_plugin_utc);
            dayjs.extend(dayjs_plugin_timezone);

            // TIME
            const mod_timeElement =document.getElementById('mod_time_js_$moduleId');

            function modUpdateTime() {
                const currentTime = dayjs()
                    .tz(`$timezone`)
                    .format(`$custom_time_format`); // YYYY-MM-DD HH:mm:ss
                mod_timeElement.textContent = currentTime;
            }

            // Update the time immediately upon script load
            modUpdateTime();

            // Then update it every second (1000 milliseconds)
            setInterval(modUpdateTime, 1000);
        });
JS;
    }
    else
    {
        $javascript = <<<JS
        document.addEventListener('DOMContentLoaded', function () {
            // Assuming you've included dayjs and the Greek locale already
            dayjs.locale(`$languageCode`);
            dayjs.extend(dayjs_plugin_utc);
            dayjs.extend(dayjs_plugin_timezone);

            // TIME
            const mod_timeElement =document.getElementById('mod_time_js_$moduleId');

            function modUpdateTime() {
                const currentTime = dayjs()
                    .format(`$custom_time_format`); // YYYY-MM-DD HH:mm:ss
                mod_timeElement.textContent = currentTime;
            }

            // Update the time immediately upon script load
            modUpdateTime();

            // Then update it every second (1000 milliseconds)
            setInterval(modUpdateTime, 1000);
        });
JS;
    }
    Factory::getDocument()->addScriptDeclaration($javascript);
}

?>

<div class="mod_datetime mod_datetime_<?php echo $moduleId; ?>">
    <?php echo $front_text; ?>
    <?php if ($datetime_in_two_rows): ?>
        <?php if (!empty($custom_date_format)): ?>
            <div class="mod_date" id="mod_date_js_<?php echo $moduleId; ?>"></div>
        <?php endif; ?>
        <?php if (!empty($between_text)): ?>
            <?php echo $between_text; ?>
        <?php endif; ?>
        <?php if ($timeformat == 2 || $timeformat == 3): ?>
            <div class="mod_time" id="mod_time_js_<?php echo $moduleId; ?>"></div>
        <?php endif; ?>
    <?php else: ?>
            <?php if (!empty($custom_date_format)): ?>
                <span class="mod_date" id="mod_date_js_<?php echo $moduleId; ?>"></span>
            <?php endif; ?>
            <?php if (!empty($between_text)): ?>
                <?php echo $between_text; ?>
            <?php endif; ?>
            <?php if ($timeformat == 2 || $timeformat == 3): ?>
                <span class="mod_time" id="mod_time_js_<?php echo $moduleId; ?>"></span>
            <?php endif; ?>
    <?php endif; ?>
    <?php echo $end_text; ?>
</div>